@@ -8,16 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import cloudcomponents.cdk_secret_key._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-github-webhook",
-    "1.50.0",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-github-webhook@1.50.0.jsii.tgz",
+    "cdk-github-webhook@2.0.0.jsii.tgz",
 )
 
 __all__ = [
